use DE_EPAGES::AmazonPayments::API::DTO::AddressInfo;
use DE_EPAGES::AmazonPayments::API::Payment qw ( ConvertAmazonAddress );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use DE_EPAGES::Object::API::Table::Country qw ( GetPKeyCountryByCode2 );
use DE_EPAGES::Test::Mock::EpagesObject;
use Test::Exception;
use Test::More;

use strict;

RunScript(
    Message => 'long',
    Sub     => sub {
        RunOnStore(
            'Store' => GetTestSite(),
            'Sub'   => sub {
                my $hIn = {
                    'firstName'    => 'Max',
                    'lastName'     => 'Mustermann',
                    'addressLine1' => 'A',
                    'addressLine2' => 'B',
                    'addressLine3' => 'C',
                    'city'         => 'London',

                    # unused
                    'county' => 'Middlesex',

                    # unused
                    'district'      => 'D',
                    'stateOrRegion' => 'E',
                    'postalCode'    => 'SE1 2BY',
                    'countryCode'   => 'GB',
                    'phone'         => '1234567890'
                };
                my $LineItem    = DE_EPAGES::Test::Mock::EpagesObject->new('DE_EPAGES::AmazonPayments::API::Object::LineItemPaymentAmazonPayments', {
                    Alias => 'MockLineItem',
                    TransID => 'S02-3029547-9718378',
                });
                my $AddressInfo = DE_EPAGES::AmazonPayments::API::DTO::AddressInfo->new($hIn);
                my $hOut        = ConvertAmazonAddress( $LineItem, $AddressInfo );
                is( $hOut->{FirstName},        $hIn->{firstName},                              'firstName' );
                is( $hOut->{LastName},         $hIn->{lastName},                               'lastName' );
                is( $hOut->{Street},           $hIn->{addressLine1},                           'addressLine1' );
                is( $hOut->{Street2},          $hIn->{addressLine2},                           'addressLine2' );
                is( $hOut->{AddressExtension}, $hIn->{addressLine3},                           'addressLine3' );
                is( $hOut->{City},             $hIn->{city},                                   'city' );
                is( $hOut->{State},            $hIn->{stateOrRegion},                          'state' );
                is( $hOut->{Zipcode},          $hIn->{postalCode},                             'postalCode' );
                is( $hOut->{CountryID},        GetPKeyCountryByCode2( $hIn->{'countryCode'} ), 'countryCode' );

                $hIn->{'countryCode'} = '123';
                $AddressInfo = DE_EPAGES::AmazonPayments::API::DTO::AddressInfo->new($hIn);
                throws_ok sub { ConvertAmazonAddress( $LineItem, $AddressInfo ); }, qr/InvalidCountry/, 'invalid or missing countryCode';
            }
        );
    }
);

done_testing;
