use strict;

use Crypt::CBC;
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::OneSaas::API::User;
use Encode qw ( decode );
use Test::More;
use Test::Exception;
use JSON;

sub Main {
    testEncrypt();
    done_testing();
}

sub testEncrypt {
    my $PlaintextToken = encode_json({
        'user' => '/Shops/DemoShop/Users/OneSaasConecctor',
        'password' => 'somesecretPassword',
        'soapUrl' => 'http://host/epages/shop.soap'
    });

    pass('plaintext token: ' . $PlaintextToken);
    my $Encrypted = DE_EPAGES::OneSaas::API::User::_Encrypt( $PlaintextToken, 'someSecretKey' );    ## no critic (ProtectPrivateSubs)
    cmp_ok( $Encrypted, 'ne', $PlaintextToken, 'not plaintext anymore: '. $Encrypted);
    is( _decrypt($Encrypted), $PlaintextToken, 'can decrypt back into plaintext' );

    throws_ok
        sub { DE_EPAGES::OneSaas::API::User::_Encrypt( $PlaintextToken, undef) }, ## no critic (ProtectPrivateSubs)
        qr/PARAMETER_MISSING.*Key/, 'encryption key is mandatory';
}

sub _decrypt {
    my ($Encrypted) = @_;
    my $Key = 'someSecretKey';
    my $Cipher = Crypt::CBC->new(
        -key     => $Key,
        -cipher  => 'Crypt::Rijndael',
        -padding => 'null',
    );

    my $Decrypted = $Cipher->decrypt_hex($Encrypted);
    return decode( 'utf8', $Decrypted );
}

RunScript( Sub => \&Main );
